#!/bin/sh

echo "Analyzing start-up log..."
errc=$(sed -n '2q;s/^.*Return code[^[:digit:]-]\+\([[:digit:]-]\+\).*$/\1/p' /var/log/initc.log)
if [ "x$errc" = "x0" ] ; then
	echo " Ok<br>"
else
	echo " error code = $errc<br>"
	grep -v "=OK" /var/log/initc.log | grep -v "Return code" | sed -n 's/.*/&\<br\>/p'
fi

cp /etc/inittab /etc/inittab.good
sed -i "s/^\(dcdc.*\)$/#\1/" /etc/inittab
kill -HUP 1
/etc/init.d/cgminer.sh stop >/dev/null 2>&1

TEST_FILE=tr.$$
echo "Starting ASIC boards test...<br>"
./inita > $TEST_FILE
sed -n 's/.*/&\<br\>/p' $TEST_FILE

# Turn ON red LED, turn ON green LED
echo low > /sys/class/gpio/gpio70/direction
echo low > /sys/class/gpio/gpio71/direction

for i in 0 1 2 3 4 5 ; do
	echo "Testing ASIC board #$i..."
	./asic_test $i 1 >$TEST_FILE 2>&1
	errc=$?
	if [ "$errc" = "0" ] ; then
		map="$(sed -n '/Good cores map/{N s/[^\n]\+\n[[:space:]]*//p}' $TEST_FILE)"
		frst="$(echo $map | cut -c 1-17)"
		scnd="$(echo $map | cut -c 19-35)"
                thrd="$(echo $map | cut -c 37-53)"
                frth="$(echo $map | cut -c 55-71)"
                nums="$(echo $map | wc -w)"
		echo "<br>Map: $map<br>"
		ok=1
		if [ "x$frst" = "xFF FF FF FF FF FF" ] ; then
			ok=0
			echo "Die #0 failed<br>"
		fi
                if [ "x$scnd" = "xFF FF FF FF FF FF" ] ; then
                        ok=0
                        echo "Die #1 failed<br>"
                fi
                if [ "x$thrd" = "xFF FF FF FF FF FF" ] ; then
                        ok=0
                        echo "Die #2 failed<br>"
                fi
                if [ "x$frth" = "xFF FF FF FF FF FF" ] ; then
                        ok=0
                        echo "Die #3 failed<br>"
                fi
                nums="$(echo $map | wc -w)"
                if [ "$nums" -ne 24 ] ; then
                        ok=0
                        echo "Some dies did not pass the test (map too short)!<br>"
                fi
		if [ "$ok" = "1" ] ; then
			echo " All dies Ok<br>"
		fi
	else
		ec=$(( errc - 256 ))
		if [ "$ec" = "-1" ] ; then
			echo " No board found<br>"
		else
			echo " error code = $ec<br>"
		fi
	fi
done
rm $TEST_FILE

echo "Restarting mining...<br>"
cd /usr/bin

INITC=initc
if [ -f /usr/bin/initc.high ] ; then
	INITC=initc.high
fi

# Turn ON red LED, turn ON green LED
echo low > /sys/class/gpio/gpio70/direction
echo low > /sys/class/gpio/gpio71/direction

exit_code=252
while [ $exit_code -eq 252 ] ; do
	echo low > /sys/class/gpio/gpio49/direction # !pwr_en
	echo low > /sys/class/gpio/gpio76/direction # reset
	sleep 1
	echo high > /sys/class/gpio/gpio76/direction # !reset
	./$INITC >/dev/null 2>&1
	exit_code=$?
done
if [[ $exit_code = 0 ]] ; then
        # Turn OFF red, Turn ON green
        echo high > /sys/class/gpio/gpio70/direction
        echo low > /sys/class/gpio/gpio71/direction
else
        # Turn ON red, Turn OFF green
        echo low > /sys/class/gpio/gpio70/direction
        echo high > /sys/class/gpio/gpio71/direction
fi

cp /etc/inittab.good /etc/inittab
kill -HUP 1
/etc/init.d/cgminer.sh start >/dev/null 2>&1
